rip_minute() extracts the minutes from a date or datetime object.

rip_minute(x)

Arguments

x

<Date / POSIXct / POSIXlt>

The vector to extract the minutes from.

Value

An integer vector the same size as x containing the minutes.

Examples

x <- as.POSIXct("1969-12-31 19:05:00", tz = "America/New_York") rip_minute(x)
#> [1] 5