rip_mday() extracts the day of the month from a date or datetime object.
rip_mday(x)
| x |
The vector to extract the day of the month from. |
|---|
An integer vector the same size as x containing the day of the
month values.
# Identical dates, but in different hours x <- as.POSIXct("1969-12-31 19:00:00", tz = "America/New_York") y <- as.POSIXct("1970-01-01 00:00:00", tz = "UTC") identical(as.numeric(x), as.numeric(y))#> [1] TRUErip_mday(x)#> [1] 31rip_mday(y)#> [1] 1