R/minute.R
rip_minute.Rd
rip_minute() extracts the minutes from a date or datetime object.
rip_minute()
rip_minute(x)
<Date / POSIXct / POSIXlt>
The vector to extract the minutes from.
An integer vector the same size as x containing the minutes.
x
x <- as.POSIXct("1969-12-31 19:05:00", tz = "America/New_York") rip_minute(x)#> [1] 5