R/second.R
rip_second.Rd
rip_second() extracts the seconds from a date or datetime object.
rip_second()
rip_second(x)
<Date / POSIXct / POSIXlt>
The vector to extract the seconds from.
A double vector the same size as x containing the seconds.
x
x <- as.POSIXct("2019-01-01 00:00:05", "UTC") rip_second(x)#> [1] 5