rip_wday() extracts the day of the week from a date or datetime object.
rip_wday(x)
| x |
The vector to extract the day of the week from. |
|---|
An integer vector the same size as x containing the day of the
week values. Monday corresponds to 1, and Sunday is 7.
# Identical dates, but in different hours x <- as.POSIXct("1969-12-31 19:00:00", tz = "America/New_York") y <- as.POSIXct("1970-01-01 00:00:00", tz = "UTC") identical(as.numeric(x), as.numeric(y))#> [1] TRUErip_wday(x)#> [1] 3rip_wday(y)#> [1] 4